@@ -116,23 +116,7 @@ net_active(struct torrent *tp)
     return tp->net->active;
 }
 
-void
-net_write32(void *buf, uint32_t num)
-{
-    uint8_t *p = buf;
-    *p = (num >> 24) & 0xff;
-    *(p + 1) = (num >> 16) & 0xff;
-    *(p + 2) = (num >> 8) & 0xff;
-    *(p + 3) = num & 0xff;
-}
-
-uint32_t
-net_read32(const void *buf)
-{
-    const uint8_t *p = buf;
-    return (uint32_t)*p << 24 | (uint32_t)*(p + 1) << 16
-        | (uint16_t)*(p + 2) << 8 | *(p + 3);
-}
+#define BLOCK_MEM_COUNT 1
 
 static unsigned long
 net_write(struct peer *p, unsigned long wmax)
@@ -143,13 +127,29 @@ net_write(struct peer *p, unsigned long wmax)
     int limited;
     ssize_t nwritten;
     unsigned long bcount;
+    int block_count = 0;
 
     limited = wmax > 0;
 
     niov = 0;
     assert((nl = BTPDQ_FIRST(&p->outq)) != NULL);
+    if (nl->nb->type == NB_TORRENTDATA)
+        block_count = 1;
     while ((niov < IOV_MAX && nl != NULL
                && (!limited || (limited && wmax > 0)))) {
+        if (nl->nb->type == NB_PIECE) {
+            if (block_count >= BLOCK_MEM_COUNT)
+                break;
+            struct net_buf *tdata = BTPDQ_NEXT(nl, entry)->nb;
+            if (tdata->buf == NULL) {
+                if (nb_torrentdata_fill(tdata, p->n->tp, nb_get_index(nl->nb),
+                        nb_get_begin(nl->nb), nb_get_length(nl->nb)) != 0) {
+                    peer_kill(p);
+                    return 0;
+                }
+            }
+            block_count++;
+        }
         if (niov > 0) {
             iov[niov].iov_base = nl->nb->buf;
             iov[niov].iov_len = nl->nb->len;
@@ -238,7 +238,7 @@ net_dispatch_msg(struct peer *p, const char *buf)
         peer_on_uninterest(p);
         break;
     case MSG_HAVE:
-        peer_on_have(p, net_read32(buf));
+        peer_on_have(p, dec_be32(buf));
         break;
     case MSG_BITFIELD:
         if (p->npieces == 0)
@@ -248,9 +248,9 @@ net_dispatch_msg(struct peer *p, const char *buf)
         break;
     case MSG_REQUEST:
         if ((p->flags & (PF_P_WANT|PF_I_CHOKE)) == PF_P_WANT) {
-            index = net_read32(buf);
-            begin = net_read32(buf + 4);
-            length = net_read32(buf + 8);
+            index = dec_be32(buf);
+            begin = dec_be32(buf + 4);
+            length = dec_be32(buf + 8);
             if ((length > PIECE_BLOCKLEN
                     || index >= p->n->tp->npieces
                     || !cm_has_piece(p->n->tp, index)
@@ -264,9 +264,9 @@ net_dispatch_msg(struct peer *p, const char *buf)
         }
         break;
     case MSG_CANCEL:
-        index = net_read32(buf);
-        begin = net_read32(buf + 4);
-        length = net_read32(buf + 8);
+        index = dec_be32(buf);
+        begin = dec_be32(buf + 4);
+        length = dec_be32(buf + 8);
         peer_on_cancel(p, index, begin, length);
         break;
     case MSG_PIECE:
@@ -341,7 +341,7 @@ net_state(struct peer *p, const char *buf)
         peer_set_in_state(p, BTP_MSGSIZE, 4);
         break;
     case BTP_MSGSIZE:
-        p->in.msg_len = net_read32(buf);
+        p->in.msg_len = dec_be32(buf);
         if (p->in.msg_len == 0)
             peer_on_keepalive(p);
         else
@@ -361,8 +361,8 @@ net_state(struct peer *p, const char *buf)
             peer_set_in_state(p, BTP_MSGBODY, p->in.msg_len - 1);
         break;
     case BTP_PIECEMETA:
-        p->in.pc_index = net_read32(buf);
-        p->in.pc_begin = net_read32(buf + 4);
+        p->in.pc_index = dec_be32(buf);
+        p->in.pc_begin = dec_be32(buf + 4);
         peer_set_in_state(p, BTP_MSGBODY, p->in.msg_len - 9);
         break;
     case BTP_MSGBODY:
@@ -655,7 +655,9 @@ net_init(void)
     m_bw_bytes_out = net_bw_limit_out;
     m_bw_bytes_in = net_bw_limit_in;
 
-    int safe_fds = min(getdtablesize(), FD_SETSIZE) * 4 / 5;
+    int safe_fds = getdtablesize() * 4 / 5;
+    if (strcmp(event_get_method(), "select") == 0)
+        safe_fds = min(safe_fds, FD_SETSIZE * 4 / 5);
     if (net_max_peers == 0 || net_max_peers > safe_fds)
         net_max_peers = safe_fds;
 
