@@ -6,14 +6,14 @@
 
 enum torrent_state {
     T_STARTING,
-    T_ACTIVE,
+    T_LEECH,
+    T_SEED,
     T_STOPPING
 };
 
 struct torrent {
     struct tlib *tl;
 
-    char relpath[RELPATH_SIZE];
     enum torrent_state state;
     int delete;
 
@@ -39,7 +39,7 @@ struct torrent *torrent_by_num(unsigned num);
 struct torrent *torrent_by_hash(const uint8_t *hash);
 
 enum ipc_err torrent_start(struct tlib *tl);
-void torrent_stop(struct torrent *tp);
+void torrent_stop(struct torrent *tp, int delete);
 
 off_t torrent_piece_size(struct torrent *tp, uint32_t piece);
 uint32_t torrent_piece_blocks(struct torrent *tp, uint32_t piece);
@@ -47,8 +47,6 @@ uint32_t torrent_block_size(struct torrent *tp, uint32_t piece,
     uint32_t nblocks, uint32_t block);
 const char *torrent_name(struct torrent *tp);
 
-void torrent_on_cm_stopped(struct torrent *tp);
-void torrent_on_cm_started(struct torrent *tp);
-void torrent_on_tr_stopped(struct torrent *tp);
+void torrent_on_tick_all(void);
 
 #endif
