@@ -4,9 +4,16 @@
 #include <stdio.h>
 #include <stdarg.h>
 
+#define max(x, y) ((x) >= (y) ? (x) : (y))
 #define min(x, y) ((x) <= (y) ? (x) : (y))
+
 #define SHAHEXSIZE 41
 
+uint32_t dec_be32(const void *buf);
+uint64_t dec_be64(const void *buf);
+void enc_be32(void *buf, uint32_t num);
+void enc_be64(void *buf, uint64_t num);
+
 int set_nonblocking(int fd);
 int set_blocking(int fd);
 
